pub struct TxEntry {
pub as_json: String,
pub as_hex: HexVec,
pub double_spend_seen: bool,
pub tx_hash: Hex<32>,
pub prunable_as_hex: HexVec,
pub prunable_hash: Hex<32>,
pub pruned_as_hex: HexVec,
pub tx_entry_type: TxEntryType,
}Expand description
Definition.
Used in crate::other::GetTransactionsResponse.
Epee
This type is only used in a JSON endpoint, so the epee implementation on this type only panics.
It is only implemented to satisfy the RPC type generator macro, which requires all objects to be serde + epee.
Fields
as_json: Stringcuprate_types::json::tx::Transaction should be used
to create this JSON string in a type-safe manner.
as_hex: HexVecdouble_spend_seen: booltx_hash: Hex<32>prunable_as_hex: HexVecprunable_hash: Hex<32>pruned_as_hex: HexVectx_entry_type: TxEntryTypeTrait Implementations
Sourceimpl<'de> Deserialize<'de> for TxEntry
Available on crate feature serde only.
impl<'de> Deserialize<'de> for TxEntry
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TxEntry
Sourceimpl Ord for TxEntry
impl Ord for TxEntry
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TxEntry
impl PartialOrd for TxEntry
impl StructuralPartialEq for TxEntry